pub fn export_stringblocks(pool: &StringPool) -> StringExpand description
Serialize a string pool as a JSON object { "0": "…", "1": "…", … }.
The returned string can be written to a file and later re-imported with
import_stringblocks.
pub fn export_stringblocks(pool: &StringPool) -> StringSerialize a string pool as a JSON object { "0": "…", "1": "…", … }.
The returned string can be written to a file and later re-imported with
import_stringblocks.